Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(668)

Unified Diff: components/signin/core/common/signin_switches.cc

Issue 1344443002: Implement new password separated sign in flow for chrome desktop. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: merged Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/signin/core/common/signin_switches.h ('k') | google_apis/gaia/gaia_urls.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/signin/core/common/signin_switches.cc
diff --git a/components/signin/core/common/signin_switches.cc b/components/signin/core/common/signin_switches.cc
index a9e549a5d40cc1ef88a0e485c1d76f3b80c61ca2..88647c86f2e8f9bb43a1fd7176478f77dbbf443e 100644
--- a/components/signin/core/common/signin_switches.cc
+++ b/components/signin/core/common/signin_switches.cc
@@ -16,7 +16,11 @@ const char kDisableAccountConsistency[] = "disable-account-consistency";
// Disables new profile management system, including new profile chooser UI.
const char kDisableNewProfileManagement[] = "disable-new-profile-management";
-// Disable sending signin scoped device id to LSO with refresh token request.
+// Disables new gaia password-separated sign in flow.
+const char kDisablePasswordSeparatedSigninFlow[] =
+ "disable-password-separated-signin-flow";
+
+// Disables sending signin scoped device id to LSO with refresh token request.
const char kDisableSigninScopedDeviceId[] = "disable-signin-scoped-device-id";
// Enables consistent identity features.
@@ -26,10 +30,14 @@ const char kEnableAccountConsistency[] = "enable-account-consistency";
// webview-based flow.
const char kEnableIframeBasedSignin[] = "enable-iframe-based-signin";
+// Enables new gaia password-separated sign in flow.
+const char kEnablePasswordSeparatedSigninFlow[] =
+ "enable-password-separated-signin-flow";
+
// Enables new profile management system, including lock mode.
const char kEnableNewProfileManagement[] = "new-profile-management";
-// Enable sending EnableRefreshTokenAnnotationRequest.
+// Enables sending EnableRefreshTokenAnnotationRequest.
extern const char kEnableRefreshTokenAnnotationRequest[] =
"enable-refresh-token-annotation-request";
« no previous file with comments | « components/signin/core/common/signin_switches.h ('k') | google_apis/gaia/gaia_urls.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698